#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

# Type responsible for managing of Oracle VM Archive Management available for each manager
module Puppet
  Type.newtype(:ovm_archive_management) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you manage Oracle VM Archive Management.
    There is only one Archive Management for each of the managers.
    Here is an example on how to use this:

        ovm_archive_management { 'default':
          archive_events_max_age    => '299',
          archive_jobs_max_age      => '20160',
          constructing_jobs_max_age => '43200',
          interval                  => '60',
          live_events_max_age       => '1440',
          live_jobs_max_age         => '60',
        }

    EOD

    restfull_type('Utilities/ArchiveManagement/attributes')

    parameter :manager_name
    parameter :name

    property  :archive_events_max_age
    property  :archive_jobs_max_age
    property  :constructing_jobs_max_age
    property  :interval
    property  :live_events_max_age
    property  :live_jobs_max_age

    # Set the name and manager_name to be the same.
    # Matching occurs on just manager_name and then is assigned twice.
    add_title_attributes(:manager_name) do
      /^(((.*)))$/
    end
  end
end
