#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

# Type responsible for managing of Oracle VM Backup Management available for each manager
module Puppet
  Type.newtype(:ovm_backup_management) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you to manage Oracle VM Backup Management.
    Here is an example on how to use this:

        ovm_backup_management { 'default':
          backup_base_directory => '/u01/app/oracle/mysql/dbbackup',
          backup_interval       => '1440',
          backup_retention      => '21',
          backup_supported      => 'true',
        }

    EOD

    restfull_type('Utilities/BackupManagement/attributes')

    parameter :manager_name
    parameter :name

    property :backup_base_directory
    property :backup_running
    property :backup_supported
    property :backup_interval
    property :backup_retention

    # Set the name and manager_name to be the same.
    # Matching occurs on just manager_name and then is assigned twice.
    add_title_attributes(:manager_name) do
      /^(((.*)))$/
    end
  end
end
