#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

module Puppet
  # Type responsible for managing of Oracle Ethernet Ports.
  Type.newtype(:ovm_ethernet_port) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you manage Oracle VM Ethernet Port.
    Here is an example on how to use this:

        ovm_ethernet_port { 'default/bond0 on ovmserver1.example.com':
          ensure      => 'present',
          ipaddresses => [{'address' => '172.28.128.19', 'configType' => 'STATIC', 'netmask' => '255.255.255.0', 'type' => 'IPV4'}],
          mtu         => '1500',
        }

    EOD

    restfull_type('EthernetPort')

    ensurable

    parameter :id
    parameter :manager_name
    parameter :name
    parameter :ethernet_port_name

    property :description
    property :ipaddresses
    property :mtu

    add_title_attributes(:ethernet_port_name)
  end
end
