#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

module Puppet
  Type.newtype(:ovm_log_management) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you manage Oracle VM Log Management.
    Here is an example on how to use this:

        ovm_log_management { 'default':
          configured_level => 'INHERITED',
          effective_level  => 'INFORMATIONAL',
          inherited_from   => 'root',
        }

    EOD

    restfull_type('Utilities/LogManagement/attributes')

    parameter :manager_name
    parameter :name

    property  :effective_level
    property  :configured_level
    property  :inherited_from

    # Set the name and manager_name to be the same.
    # Matching occurs on just manager_name and then is assigned twice.
    add_title_attributes(:manager_name) do
      /^(((.*)))$/
    end
  end
end
