#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

module Puppet
  Type.newtype(:ovm_mac_management) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you manage Oracle VM Mac Management.
    Here is an example on how to use this:

        ovm_mac_management { 'default':
          address_range_end   => 'dd:12:12',
          address_range_start => '00:00:00',
          oui                 => '00:21:f6:',
        }

    EOD

    restfull_type('Utilities/MacManagement/attributes')

    parameter :manager_name
    parameter :name

    property  :oui
    property  :address_range_start
    property  :address_range_end

    # Set the name and manager_name to be the same.
    # Matching occurs on just manager_name and then is assigned twice.
    add_title_attributes(:manager_name) do
      /^(((.*)))$/
    end
  end
end
