#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:presented_to_servers,
            :array_matching => :all,
            :parent => Puppet::Parameter::OvmProperty) do
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Ovm::Data

  desc <<-EOD
  Specifies the servers that this repository is presented to.
  Here is example how to do this:

      ovm_repository { ...
        ...
        presented_to_servers => ['server1.example.com','server2.example.com'],
        ...
      }

  EOD

  maps_to('presentedServerIds.name')

  on_apply do
    present(to_present)
    unpresent(to_unpresent)
    nil
  end

  def present(servers)
    present_call(:present, servers)
  end

  def unpresent(servers)
    present_call(:unpresent, servers)
  end

  private

  def present_call(action, servers)
    with_manager_connection do |connection|
      servers.each do |server|
        server_id = server_id_for( server)
        Puppet.debug("#{action}ing server #{server} on repo #{resource.name}")
        connection.validated(:put, "/ovm/core/wsapi/rest/Repository/#{id}/#{action}" ,server_id)
      end
    end
  end

  def to_present
    request_value - current_value
  end

  def to_unpresent
    current_value - request_value
  end

  def current_value
    provider.presented_to_servers == :absent ? [] : provider.presented_to_servers
  end

  def request_value
    value == :absent ? [] : value
  end

  def id
    provider.id == :absent ? repository_id_for(resource.repository_name)['value'] : provider.id
  end
end
