#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/ovm/core'

module Puppet
  # Type responsible for managing of ovm servers pools available for manager
  Type.newtype(:ovm_server_pool) do
    include Puppet_X::EnterpriseModules::Ovm::Type

    desc <<-EOD
    This resource allows you manage VM Server Pools.
    Here is an example on how to use this:

        ovm_server_pool { 'default/server_pool_1':
          ensure          => 'present',
          description     => 'Server Pool number 1',
          keymap          => 'en-us',
          virtual_ip      => '123.10.1.1',
          vm_start_policy => 'BEST_SERVER',
        }

    EOD

    restfull_type('ServerPool')

    ensurable

    parameter :id
    parameter :manager_name
    parameter :name
    parameter :server_pool_name

    property  :description
    property  :keymap
    property  :locked
    property  :master_server
    property  :secure_vm_migrate
    property  :servers
    property  :tags
    property  :virtual_ip
    property  :vm_start_policy

    add_title_attributes(:server_pool_name)
  end
end
