#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:size, :parent => Puppet::Parameter::OvmProperty) do
  include EasyType::Mungers::Size
  include Puppet_X::EnterpriseModules::Ovm::Data
  include EasyType::Validators::Integer

  desc <<-EOD
  The size of the disk. If this is a sparse image, this number does not reflect
  the actual size of the image on disk, but rather the maximum size of the file.
  For a non-sparse image this is the same as the size of the file on disk.
  This field not applies to the `VIRTUAL_CDROM` type of Virtual Disk.
  Here is example how to do this:

      ovm_virtual_disk { ...
        ...
        size =>
        ...
      }

  EOD

  validate do |value|
    #
    # VIRTUAL_CDROM iso size can be prime number and be non divisible by 2
    #
    disk_type = resource.original_parameters[:disk_type]
    if value.is_a?(Integer) && value.div(4096) != 0 && disk_type != 'VIRTUAL_CDROM'
      fail "Size must be a multiple of: 4,096 bytes."
    end
  end

  on_modify do
    Puppet.debug("Resizing virtual disk #{resource.virtual_disk_name} on repo #{resource.name} to #{value}")
    path = "#{resource.restfull_path}/#{provider.id}/resize"
    resource.with_manager_connection do |connection|
      repository_id = repository_id_for(resource.repository_name)['value']
      parameters    =  URI.encode_www_form('sparse' => resource.sparse, 'size' => value)
      connection.validated(:put, "/ovm/core/wsapi/rest/VirtualDisk/#{provider.id}/resize?#{parameters}" , resource.update_payload)
    end
  end
end
