#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:vm_run_state, :parent => Puppet::Parameter::OvmProperty) do
  desc <<-EOD
  Specifies Running State for Oracle Virtual Machine.
  Here is example how to do this:

      ovm_vm { 'default/mypool1/ovmserver1.example.com:myvm2':
        ensure          => 'present',
        vm_run_state    => 'STOPPED',
      }

  EOD

  on_modify do
    resource.with_manager_connection do |connection|
      modify_path =  case
                     when value == 'RUNNING' && provider.vm_run_state == 'STOPPED'
                       "#{resource.update_path}/start"
                     when value == 'STOPPED' && provider.vm_run_state == 'RUNNING'
                       "#{resource.update_path}/stop"
                     else
                       Puppet.info 'Invalid runnning state'
                     end
      connection.validated(:put, modify_path, {})
    end
    nil
  end
end
