#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:admin_servers,
            :array_matching => :all,
            :parent => Puppet::Parameter::OvmProperty) do
  include EasyType::ArrayProperty
  include Puppet_X::EnterpriseModules::Ovm::Data

  desc <<-EOD
  The admin_server_names is used only in the process of file server discovery.
  Here is example how to do this:

      ovm_file_server { ...
        ...
        admin_servers => ['ovs33.fr.oracle.com']
        ...
      }

  or:

      ovm_storage_array { ...
      ...
      admin_servers => ['ovs33.fr.oracle.com']
      ...
    }

  EOD

  defaultto([])

  maps_to('adminServerIds.name')

  on_apply do
    add_servers(to_add)
    remove_servers(to_remove)
    nil
  end

  def add_servers(servers)
    modify(:add, servers)
  end

  def remove_servers(servers)
    modify(:remove, servers)
  end

  private

  def modify(action, servers)
    with_manager_connection do |connection|
      servers.each do |server|
        server_id = server_id_for( server)
        Puppet.debug("#{action}ing adminserver #{server} on #{resource.name}")
        connection.validated(:put, "/ovm/core/wsapi/rest/#{resource.restfull_type}/#{id}/#{action}AdminServer" ,server_id)
      end
    end
  end

  def to_add
    request_value - current_value
  end

  def to_remove
    current_value - request_value
  end

  def current_value
    provider.admin_servers == :absent ? [] : provider.admin_servers
  end

  def request_value
    value == :absent ? [] : value
  end

  def id
    id = case resource.restfull_type
    when 'StorageArray' then
      storage_array_id_for(resource.storage_array_name)['value']
    when 'FileServer' then
      file_server_id_for(resource.file_server_name)['value']
    else
      fail 'Invalid restfull type found/'
    end
    provider.id == :absent ? id : provider.id
  end
end

