#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet_X
  module EnterpriseModules
    module Ovm
      class JobValidator
        def initialize(job_status, connection)
          @job_status = job_status
          @job_id     = @job_status['id']['value']
          @connection = connection
          @job_object = nil
        end

        def call
          fail 'Internal error in job validator' unless @job_status['id']['type'] == 'com.oracle.ovm.mgr.ws.model.Job'
          return true if @job_status['done'] == true
          perform_checks
        end

        private

        def perform_checks
          begin
            sleep(0.1)
            @job_object = @connection.get("/ovm/core/wsapi/rest/Job/#{@job_id}").body
          end while job_not_done?
          fail @job_object['error']['message'] if job_failure?
        end

        def job_failure?
          @job_object['jobRunState'] == 'FAILURE'
        end

        def job_not_done?
          @job_object['done'] == false
        end
      end
    end
  end
end
