#
# See the file "LICENSE" for the full license governing this code.
#
class Puppet::Parameter::OvmProperty < Puppet::Property
  include EasyType

  def self.translate_to_resource(raw_resource)
    return value_for(@path, raw_resource) if @path
    key = name.to_s.split('_').collect(&:capitalize).join.sub(/^[A-Z]/, &:downcase)
    raw_resource.fetch(key)
  end

  def self.maps_to(path)
    @path = path
  end

  def self.value_for(key, resource)
    keys = key.split('.')
    if array_matching == :all
      array_key = keys.shift()
      values = resource[array_key]
      #
      # When only a single value is specified the API return a Hash instead of
      # an Array with 1 element. That is why we always cast to an Array.
      #
      values = [] if values.nil?
      values = Array[values].flatten
      values.collect do |element|
        keys.reduce(element) { |value, key| value[key] }
      end
    else
      keys.reduce(resource) { |value, key| value[key] }
    end
  end

  [:create_payload, :update_payload].each do |action|
    class_eval(<<-CODE, __FILE__, __LINE__ + 1)
      # @nodoc
      # @private
      def self.#{action}(&block)
        define_method(:#{action}, &block) if block
      end
    CODE
  end

end
