#
# See the file "LICENSE" for the full license governing this code.
#
#
# Install the Oracle VM Manager software
#
class ovm_config::software()
{
  include ::ovm_config::installovmm

  if ::ovm_config::installovmm::ignore_checks {
    $ignore_checks = '--noprereq'
  } else {
    $ignore_checks = ''
  }

  unless defined(File['/u01']) {
    file {'/u01':
      ensure => 'directory',
      owner  => 'oracle',
      group  => 'oinstall',
    }
  }

  unless $::ovmm_installed {

    file { '/tmp/config.yml':
      ensure  => 'present',
      content => epp('ovm_config/config.yaml.epp',
        {
          db_port      => $::ovm_config::installovmm::db_port,
          db_schema    => $::ovm_config::installovmm::db_schema,
          db_password  => $::ovm_config::installovmm::db_password,
          wls_username => $::ovm_config::installovmm::wls_username,
          wls_password => $::ovm_config::installovmm::wls_password,
          ovm_username => $::ovm_config::installovmm::ovm_username,
          ovm_password => $::ovm_config::installovmm::ovm_password,
          fqdn         => $::ovm_config::installovmm::fqdn
        }),
    }

    -> exec {'Installed OVMM':
      command   => "${::ovm_config::installovmm::source}/runInstaller.sh --config=/tmp/config.yml --assumeyes --installtype=Install --cleanup ${ignore_checks}",
      timeout   => 0,
      unless    => '/bin/test -d /u01/app/oracle/ovm-manager-3/',
      logoutput => $::ovm_config::installovmm::logoutput,
    }

    -> exec {'remove_temporary_file':
      command => '/bin/rm -f /tmp/config.yml',
    }
  }
}
